@@ -6,14 +6,16 @@
 
     Additional tests by a host of SciPy developers.
 """
+from __future__ import division, print_function, absolute_import
 
-from numpy.testing import TestCase, rand, assert_, assert_equal, \
+import sys
+
+from numpy.testing import TestCase, assert_, assert_equal, \
     assert_almost_equal, assert_array_almost_equal, assert_array_equal, \
     assert_approx_equal, assert_raises, run_module_suite, \
     assert_allclose, dec
-from numpy import array, arange, zeros, ravel, float32, float64, power
+from numpy import array, arange, float32, float64, power
 import numpy as np
-import sys
 
 import scipy.stats as stats
 
@@ -741,6 +743,19 @@ class TestRegression(TestCase):
         res = (1.0, 5.0, 0.98229948625750, 7.45259691e-008, 0.063564172616372733)
         assert_array_almost_equal(stats.linregress(x,y),res,decimal=14)
 
+    def test_regress_simple_negative_cor(self):
+        # If the slope of the regression is negative the factor R tend to -1 not 1.
+        # Sometimes rounding errors makes it < -1 leading to stderr being NaN
+        a, n = 1e-71, 100000
+        x = np.linspace(a, 2 * a, n)
+        y = np.linspace(2 * a, a, n)
+        stats.linregress(x, y)
+        res = stats.linregress(x, y)
+        assert_(res[2] >= -1)  # propagated numerical errors were not corrected
+        assert_almost_equal(res[2], -1)  # perfect negative correlation case
+        assert_(not np.isnan(res[4]))  # stderr should stay finite
+
+
 class TestHistogram(TestCase):
     """ Tests that histogram works as it should, and keeps old behaviour
     """
@@ -992,9 +1007,9 @@ class TestHMean(TestCase):
 
 class TestScoreatpercentile(TestCase):
     def setUp(self):
-        self.a1 = [3,4,5,10,-3,-5,6]
-        self.a2 = [3,-6,-2,8,7,4,2,1]
-        self.a3 = [3.,4,5,10,-3,-5,-6,7.0]
+        self.a1 = [3, 4, 5, 10, -3, -5, 6]
+        self.a2 = [3, -6, -2, 8, 7, 4, 2, 1]
+        self.a3 = [3., 4, 5, 10, -3, -5, -6, 7.0]
 
     def test_basic(self):
         x = arange(8) * 0.5
@@ -1008,25 +1023,25 @@ class TestScoreatpercentile(TestCase):
                    [4, 4, 3],
                    [1, 1, 1],
                    [1, 1, 1]])
-        assert_array_equal(stats.scoreatpercentile(x, 50), [1,1,1])
+        assert_array_equal(stats.scoreatpercentile(x, 50), [1, 1, 1])
 
     def test_fraction(self):
         scoreatperc = stats.scoreatpercentile
 
         # Test defaults
-        assert_equal(scoreatperc(range(10), 50), 4.5)
-        assert_equal(scoreatperc(range(10), 50, (2,7)), 4.5)
-        assert_equal(scoreatperc(range(100), 50, limit=(1, 8)), 4.5)
+        assert_equal(scoreatperc(list(range(10)), 50), 4.5)
+        assert_equal(scoreatperc(list(range(10)), 50, (2,7)), 4.5)
+        assert_equal(scoreatperc(list(range(100)), 50, limit=(1, 8)), 4.5)
         assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, (10,100)), 55)
         assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, (1,10)), 5.5)
 
         # explicitly specify interpolation_method 'fraction' (the default)
-        assert_equal(scoreatperc(range(10), 50, interpolation_method='fraction'),
+        assert_equal(scoreatperc(list(range(10)), 50, interpolation_method='fraction'),
                      4.5)
-        assert_equal(scoreatperc(range(10), 50, limit=(2, 7),
+        assert_equal(scoreatperc(list(range(10)), 50, limit=(2, 7),
                                  interpolation_method='fraction'),
                      4.5)
-        assert_equal(scoreatperc(range(100), 50, limit=(1, 8),
+        assert_equal(scoreatperc(list(range(100)), 50, limit=(1, 8),
                                  interpolation_method='fraction'),
                      4.5)
         assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, (10, 100),
@@ -1040,27 +1055,49 @@ class TestScoreatpercentile(TestCase):
         scoreatperc = stats.scoreatpercentile
 
         # interpolation_method 'lower'/'higher'
-        assert_equal(scoreatperc(range(10), 50,
+        assert_equal(scoreatperc(list(range(10)), 50,
                                  interpolation_method='lower'), 4)
-        assert_equal(scoreatperc(range(10), 50,
+        assert_equal(scoreatperc(list(range(10)), 50,
                                  interpolation_method='higher'), 5)
-        assert_equal(scoreatperc(range(10), 50, (2,7),
+        assert_equal(scoreatperc(list(range(10)), 50, (2,7),
                                  interpolation_method='lower'), 4)
-        assert_equal(scoreatperc(range(10), 50, limit=(2,7),
+        assert_equal(scoreatperc(list(range(10)), 50, limit=(2,7),
                                  interpolation_method='higher'), 5)
-        assert_equal(scoreatperc(range(100), 50, (1,8),
+        assert_equal(scoreatperc(list(range(100)), 50, (1,8),
                                  interpolation_method='lower'), 4)
-        assert_equal(scoreatperc(range(100), 50, (1,8),
+        assert_equal(scoreatperc(list(range(100)), 50, (1,8),
                                  interpolation_method='higher'), 5)
-        assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, (10,100),
+        assert_equal(scoreatperc(np.array([1, 10, 100]), 50, (10, 100),
                                  interpolation_method='lower'), 10)
-        assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, limit=(10, 100),
+        assert_equal(scoreatperc(np.array([1, 10, 100]), 50, limit=(10, 100),
                                  interpolation_method='higher'), 100)
-        assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, (1,10),
+        assert_equal(scoreatperc(np.array([1, 10, 100]), 50, (1, 10),
                                  interpolation_method='lower'), 1)
-        assert_equal(scoreatperc(np.array([1, 10 ,100]), 50, limit=(1,10),
+        assert_equal(scoreatperc(np.array([1, 10, 100]), 50, limit=(1, 10),
                                  interpolation_method='higher'), 10)
 
+    def test_sequence(self):
+        x = arange(8) * 0.5
+        assert_equal(stats.scoreatpercentile(x, [0, 100, 50]), [0, 3.5, 1.75])
+
+    def test_axis(self):
+        scoreatperc = stats.scoreatpercentile
+        x = arange(12).reshape(3, 4)
+
+        assert_equal(scoreatperc(x, (25, 50, 100)), [2.75, 5.5, 11.0])
+
+        r0 = [[2, 3, 4, 5], [4, 5, 6, 7], [8, 9, 10, 11]]
+        assert_equal(scoreatperc(x, (25, 50, 100), axis=0), r0)
+
+        r1 = [[0.75, 4.75, 8.75], [1.5, 5.5, 9.5], [3, 7, 11]]
+        assert_equal(scoreatperc(x, (25, 50, 100), axis=1), r1)
+
+    def test_exception(self):
+        assert_raises(ValueError, stats.scoreatpercentile, [1, 2], 56,
+            interpolation_method='foobar')
+        assert_raises(ValueError, stats.scoreatpercentile, [1], 101)
+        assert_raises(ValueError, stats.scoreatpercentile, [1], -1)
+
 
 class TestCMedian(TestCase):
     def test_basic(self):
@@ -1586,7 +1623,7 @@ def test_ttest_ind():
         np.seterr(**olderr)
 
 def test_ttest_ind_with_uneq_var():
-      
+
     # check vs. R
     a = (1, 2, 3)
     b = (1.1, 2.9, 4.2)
@@ -1594,7 +1631,7 @@ def test_ttest_ind_with_uneq_var():
     tr = -0.68649512735572582
     t, p = stats.ttest_ind(a, b, equal_var = False)
     assert_array_almost_equal([t,p], [tr, pr])
-    
+
     a = (1, 2, 3, 4)
     pr = 0.84354139131608286
     tr = -0.2108663315950719
@@ -1631,7 +1668,7 @@ def test_ttest_ind_with_uneq_var():
     assert_array_almost_equal(np.abs(p), pr)
     assert_equal(t.shape, (2, 3))
 
-    t,p = stats.ttest_ind(np.rollaxis(rvs1_3D,2), np.rollaxis(rvs2_3D,2), 
+    t,p = stats.ttest_ind(np.rollaxis(rvs1_3D,2), np.rollaxis(rvs2_3D,2),
                                    axis=2, equal_var = False)
     assert_array_almost_equal(np.abs(t), np.abs(tr))
     assert_array_almost_equal(np.abs(p), pr)
@@ -1723,6 +1760,33 @@ def test_normalitytests():
     yield assert_array_almost_equal, stats.skewtest(x), (st_skew, pv_skew)
     yield assert_array_almost_equal, stats.kurtosistest(x), (st_kurt, pv_kurt)
 
+
+class TestJarqueBera(TestCase):
+    def test_jarque_bera_stats(self):
+        np.random.seed(987654321)
+        x = np.random.normal(0, 1, 100000)
+        y = np.random.chisquare(10000, 100000)
+        z = np.random.rayleigh(1, 100000)
+
+        assert_(stats.jarque_bera(x)[1] > stats.jarque_bera(y)[1])
+        assert_(stats.jarque_bera(x)[1] > stats.jarque_bera(z)[1])
+        assert_(stats.jarque_bera(y)[1] > stats.jarque_bera(z)[1])
+
+    def test_jarque_bera_array_like(self):
+        np.random.seed(987654321)
+        x = np.random.normal(0, 1, 100000)
+
+        JB1, p1 = stats.jarque_bera(list(x))
+        JB2, p2 = stats.jarque_bera(tuple(x))
+        JB3, p3 = stats.jarque_bera(x.reshape(2, 50000))
+
+        assert_(JB1 == JB2 == JB3)
+        assert_(p1 == p2 == p3)
+
+    def test_jarque_bera_size(self):
+        assert_raises(ValueError, stats.jarque_bera, [])
+
+
 def test_skewtest_too_few_samples():
     """Regression test for ticket #1492.
 
