@@ -30,6 +30,7 @@
     along with the path information to its module, are also stored in a
     persistent catalog for future use by python sessions.
 """
+from __future__ import absolute_import, print_function
 
 import os
 import sys
@@ -42,7 +43,7 @@ try:
     import shelve
     dumb = 0
 except ImportError:
-    import scipy.io.dumb_shelve as shelve
+    from . import _dumb_shelve as shelve
     dumb = 1
 
 #For testing...
@@ -104,7 +105,7 @@ def unique_file(d,expr):
     #base = 'scipy_compile'
     base = expr_to_filename(expr)
     for i in xrange(1000000):
-        fname = base + `i`
+        fname = base + repr(i)
         if not (fname+'.cpp' in files or
                 fname+'.o' in files or
                 fname+'.so' in files or
@@ -114,30 +115,21 @@ def unique_file(d,expr):
             break
     return os.path.join(d,fname)
 
-def create_dir(p):
-    """ Create a directory and any necessary intermediate directories."""
-    if not os.path.exists(p):
-        try:
-            os.mkdir(p)
-        except OSError:
-            # perhaps one or more intermediate path components don't exist
-            # try to create them
-            base,dir = os.path.split(p)
-            create_dir(base)
-            # don't enclose this one in try/except - we want the user to
-            # get failure info
-            os.mkdir(p)
-
 def is_writable(dir):
     """Determine whether a given directory is writable in a portable manner.
 
-    :Parameters:
-     - dir: string
-       A string represeting a path to a directory on the filesystem.
+    Parameters
+    ----------
+    dir : str
+        A string represeting a path to a directory on the filesystem.
 
-    :Returns:
-      True or False.
+    Returns
+    -------
+    res : bool
+        True or False.
     """
+    if not os.path.isdir(dir):
+        return False
 
     # Do NOT use a hardcoded name here due to the danger from race conditions
     # on NFS when multiple processes are accessing the same base directory in
@@ -191,7 +183,7 @@ def default_dir():
         except KeyError:
             pass
 
-        temp_dir = `os.getuid()` + '_' + python_name
+        temp_dir = repr(os.getuid()) + '_' + python_name
         path_candidates.append(os.path.join(tempfile.gettempdir(), temp_dir))
     else:
         path_candidates.append(os.path.join(tempfile.gettempdir(),
@@ -200,15 +192,17 @@ def default_dir():
     writable = False
     for path in path_candidates:
         if not os.path.exists(path):
-            create_dir(path)
-            os.chmod(path, 0700) # make it only accessible by this user.
+            try:
+                os.makedirs(path, mode=0o700)
+            except OSError:
+                continue
         if is_writable(path):
             writable = True
             break
 
     if not writable:
-        print 'warning: default directory is not write accessible.'
-        print 'default:', path
+        print('warning: default directory is not write accessible.')
+        print('default:', path)
 
     # Cache the default dir path so that this function returns quickly after
     # being called once (nothing in it should change after the first call)
@@ -223,17 +217,16 @@ def intermediate_dir():
     python_name = "python%d%d_intermediate" % tuple(sys.version_info[:2])
     path = os.path.join(tempfile.gettempdir(),"%s"%whoami(),python_name)
     if not os.path.exists(path):
-        create_dir(path)
+        os.makedirs(path, mode=0o700)
     return path
 
 def default_temp_dir():
     path = os.path.join(default_dir(),'temp')
     if not os.path.exists(path):
-        create_dir(path)
-        os.chmod(path,0700) # make it only accessible by this user.
+        os.makedirs(path, mode=0o700)
     if not is_writable(path):
-        print 'warning: default directory is not write accessible.'
-        print 'default:', path
+        print('warning: default directory is not write accessible.')
+        print('default:', path)
     return path
 
 
@@ -245,7 +238,7 @@ def os_dependent_catalog_name():
         bases the name of the value returned by sys.platform and the
         version of python being run.  If this isn't enough to descriminate
         on some platforms, we can try to add other info.  It has
-        occured to me that if we get fancy enough to optimize for different
+        occurred to me that if we get fancy enough to optimize for different
         architectures, then chip type might be added to the catalog name also.
     """
     version = '%d%d' % sys.version_info[:2]
@@ -295,7 +288,7 @@ def get_catalog(module_path,mode='r'):
     """
     if mode not in ['c','r','w','n']:
         msg = " mode must be 'c', 'n', 'r', or 'w'.  See anydbm for more info"
-        raise ValueError, msg
+        raise ValueError(msg)
     catalog_file = catalog_path(module_path)
     if (catalog_file is not None) \
            and ((dumb and os.path.exists(catalog_file+'.dat')) \
@@ -562,14 +555,14 @@ class catalog(object):
         try:
             writable_cat = get_catalog(catalog_path,'w')
         except:
-            print 'warning: unable to repair catalog entry\n %s\n in\n %s' % \
-                  (code,catalog_path)
+            print('warning: unable to repair catalog entry\n %s\n in\n %s' % \
+                  (code,catalog_path))
             # shelve doesn't guarantee flushing, so it's safest to explicitly
             # close the catalog
             writable_cat.close()
             return
         if code in writable_cat:
-            print 'repairing catalog by removing key'
+            print('repairing catalog by removing key')
             del writable_cat[code]
 
         # it is possible that the path key doesn't exist (if the function
@@ -673,14 +666,14 @@ class catalog(object):
         if cat is None:
             cat_dir = default_dir()
             cat_file = catalog_path(cat_dir)
-            print 'problems with default catalog -- removing'
+            print('problems with default catalog -- removing')
             import glob
             files = glob.glob(cat_file+'*')
             for f in files:
                 os.remove(f)
             cat = get_catalog(cat_dir,mode)
         if cat is None:
-            raise ValueError, 'Failed to access a catalog for storing functions'
+            raise ValueError('Failed to access a catalog for storing functions')
         # Prabhu was getting some corrupt catalog errors.  I'll put a try/except
         # to protect against this, but should really try and track down the issue.
         function_list = [function]
